aboutsummaryrefslogtreecommitdiffstats
path: root/include/ruby/impl/module.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/module.h')
-rw-r--r--include/ruby/impl/module.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/module.h b/include/ruby/impl/module.h
index 23c001e676..3c8a9688de 100644
--- a/include/ruby/impl/module.h
+++ b/include/ruby/impl/module.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_MODULE_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_MODULE_H
+#ifndef RBIMPL_MODULE_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_MODULE_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -23,7 +23,7 @@
#include "ruby/impl/dllexport.h"
#include "ruby/impl/value.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
VALUE rb_define_class(const char*,VALUE);
VALUE rb_define_module(const char*);
@@ -34,6 +34,6 @@ void rb_include_module(VALUE,VALUE);
void rb_extend_object(VALUE,VALUE);
void rb_prepend_module(VALUE,VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_MODULE_H */
+#endif /* RBIMPL_MODULE_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file